@@ -38,13 +38,11 @@ typedef void (*ReplySwapFunc)(ClientPtr, int, void *);
 
 extern InitialFunc InitialVector[3];
 extern ReplySwapFunc ReplySwapVector[NUM_PROC_VECTORS];
+extern EventSwapFunc EventSwapVector[NUM_EVENT_VECTORS];
 
 /* FIXME: this is derived from fontstruct.h; should integrate it */
 
 /* difs/atom.c */
-extern Atom MakeAtom ( const char *string, unsigned len, Bool makeit );
-extern int ValidAtom ( Atom atom );
-extern char * NameForAtom ( Atom atom );
 extern void InitAtoms ( void );
 
 /* difs/charinfo.c */
@@ -66,6 +64,13 @@ extern int StartListFontsWithInfo ( ClientPtr client, int length, unsigned char
 extern int LoadGlyphRanges ( ClientPtr client, FontPtr pfont, Bool range_flag, int num_ranges, int item_size, fsChar2b *data );
 extern FontPtr find_old_font ( FSID id );
 extern void DeleteClientFontStuff ( ClientPtr client );
+extern int xfs_init_fs_handlers(FontPathElementPtr fpe,
+                                FontBlockHandlerProcPtr block_handler);
+
+extern void xfs_remove_fs_handlers(FontPathElementPtr fpe,
+                                   FontBlockHandlerProcPtr block_handler,
+                                   Bool all);
+extern int register_fpe_funcs(const xfont2_fpe_funcs_rec *funcs);
 
 /* difs/fontinfo.c */
 extern int convert_props ( FontInfoPtr pinfo, fsPropInfo **props );
